@@ -1,7 +1,7 @@
 package Minion::Backend::Mango;
 use Mojo::Base 'Minion::Backend';
 
-our $VERSION = '0.99';
+our $VERSION = '1.00';
 
 use Mango;
 use Mango::BSON qw(bson_oid bson_time bson_doc);
@@ -64,8 +64,9 @@ sub list_jobs {
   my ($self, $skip, $limit, $options) = @_;
 
   my $cursor = $self->jobs->find({state => {'$exists' => \1}});
-  $cursor->query->{state} = $options->{state} if $options->{state};
-  $cursor->query->{task}  = $options->{task}  if $options->{task};
+  for (qw/state task queue/) {
+    $cursor->query->{$_} = $options->{$_} if $options->{$_};
+  }
   $cursor->sort({_id => -1})->skip($skip)->limit($limit);
 
   return [map { $self->_job_info($_) } @{$cursor->all}];
@@ -108,7 +109,7 @@ sub repair {
 
   # Abandoned jobs
   my $jobs = $self->jobs;
-  my $cursor = $jobs->find({state => 'active'}, {_id => 1, retries => 1});
+  my $cursor = $jobs->find({state => 'active'}, {_id => 1, retries => 1, worker => 1});
   while (my $job = $cursor->next) {
     $self->fail_job($job->{_id}, $job->{retries}, 'Worker went away')
       unless $workers->find_one($job->{worker});
@@ -119,7 +120,12 @@ sub repair {
     {state => 'finished', finished => {'$lt' => bson_time((time - $minion->remove_after) * 1000)}});
 }
 
-sub reset { $_->options && $_->drop for $_[0]->workers, $_[0]->jobs }
+sub reset {
+  my $self = shift;
+
+  $_->options && $_->drop for $self->workers, $self->jobs, $self->notifications;
+  delete $self->{capped};
+}
 
 sub retry_job {
   my ($self, $oid, $retries) = (shift, shift, shift);
@@ -149,6 +155,7 @@ sub stats {
   my $all     = $workers->find->count;
   my $stats   = {active_workers => $active, inactive_workers => $all - $active};
   $stats->{"${_}_jobs"} = $jobs->find({state => $_})->count for qw(active failed finished inactive);
+  $stats->{delayed_jobs} = $jobs->find({state => 'inactive', delayed => {'$gt' => bson_time}})->count;
   return $stats;
 }
 
@@ -160,8 +167,8 @@ sub _await {
   my $self = shift;
 
   my $last = $self->{last} //= bson_oid;
-  my $cursor =
-    $self->notifications->find({_id => {'$gt' => $last}, c => 'created'})->tailable(1)->await_data(1);
+  my $cursor
+    = $self->notifications->find({_id => {'$gt' => $last}, c => 'created'})->tailable(1)->await_data(1);
   return undef unless my $doc = $cursor->next || $cursor->next;
   $self->{last} = $doc->{_id};
   return 1;
@@ -396,6 +403,12 @@ These options are currently available:
 
 =over 2
 
+=item queue
+
+  queue => 'important'
+
+List only jobs in this queue.
+
 =item state
 
   state => 'inactive'
